@@ -296,14 +296,17 @@ extAddOverlap(tbelow, tabove)
     struct overlap ov;
     TileType ta, tb;
     CoupleKey ck;
-    int pNum;
+    int pNum, oa, ob;
     CapValue c;
 
-    /* Do nothing if both tiles are connected */
+    /* Check if both tiles are connected.  If they are, we don't need   */
+    /* to check for shielding material, and we don't want to add any    */
+    /* coupling capacitance between them.  However, we *do* want to     */
+    /* subtract off any substrate (area) capacitance previously added   */
+    /* (Correction made 4/29/04 by Tim from a tip by Jeff Sondeen).     */
+
     rabove = (NodeRegion *) extGetRegion(tabove);
     rbelow = (NodeRegion *) extGetRegion(tbelow);
-    if (rabove == rbelow)
-	return (0);
 
     /* Compute the area of overlap */
     ov.o_clip.r_xbot = MAX(LEFT(tbelow), LEFT(tabove));
@@ -322,6 +325,7 @@ extAddOverlap(tbelow, tabove)
      * Deduct the area shielded from the area of the overlap, so we adjust
      * the overlap capacitance correspondingly.
      */
+
     if (ov.o_pmask = ExtCurStyle->exts_overlapShieldPlanes[ta][tb])
     {
 	ov.o_tmask = ExtCurStyle->exts_overlapShieldTypes[ta][tb];
@@ -348,10 +352,8 @@ extAddOverlap(tbelow, tabove)
     /* If any capacitance remains, add this record to the table */
     if (ov.o_area > 0)
     {
-	int oa = 
-	    ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[TiGetType(tabove)]];
-	int ob = 
-	    ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[TiGetType(tbelow)]];
+	oa = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[ta]];
+	ob = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[tb]];
 	if (oa > ob)
 	{
 	    /*
@@ -371,6 +373,9 @@ extAddOverlap(tbelow, tabove)
 	    extNregAdjustCap(rabove, 0.0, 
 		"obsolete_overlap (skipped, wrong direction)");
 	    
+	/* If the regions are the same, skip this part */
+	if (rabove == rbelow) return (0);
+	
 	/* Find the coupling hash record */
 	if (rabove < rbelow) ck.ck_1 = rabove, ck.ck_2 = rbelow;
 	else ck.ck_1 = rbelow, ck.ck_2 = rabove;
@@ -384,7 +389,6 @@ extAddOverlap(tbelow, tabove)
 		ov.o_area, "overlap");
 	extSetCapValue(he, c);
     }
-
     return (0);
 }
 
@@ -627,9 +631,6 @@ extSideOverlap(tp, bp)
     CapValue cap;
     CoupleKey ck;
 
-    if (rtp == rbp)
-	return (0);
-
     if (bp->b_segment.r_xtop == bp->b_segment.r_xbot)
     {
 	length = MIN(bp->b_segment.r_ytop, TOP(tp))
@@ -650,6 +651,10 @@ extSideOverlap(tp, bp)
     ta = TiGetType(bp->b_inside);
     tb = TiGetType(tp);
 
+    /* Avoid doing the code below if we're just going to return without */
+    /* changing anything.                                               */
+    if ((tb == TT_SPACE) && (rtp == rbp)) return (0);
+
     /* Apply each rule, incorporating shielding into the edge length. */
     cap = (CapValue) 0;
     for (e = extOverlapList; e; e = e->ec_next)
@@ -693,13 +698,14 @@ extSideOverlap(tp, bp)
 		    break;
 		}
 	    }
-	    cap += e->ec_cap * ov.o_area;
+	    if (rtp != rbp)
+		cap += e->ec_cap * ov.o_area;
 	    areaAccountedFor += ov.o_area;
 	}
     }
     
     /* Add in the new capacitance. */
-    if (TiGetType(tp) == TT_SPACE)
+    if (tb == TT_SPACE)
     {
 	/* Is tp a space tile?  If so, extGetRegion points to garbage;  	
 	 * make terminal 2 point to ground.
@@ -709,16 +715,8 @@ extSideOverlap(tp, bp)
     }
     else
     {
-	int oa;
-	int ob;
-	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
-	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
-	he = HashFind(extCoupleHashPtr, (char *) &ck);
-	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
-	extSetCapValue(he, cap + extGetCapValue(he));
-
-	oa = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[TiGetType(bp->b_inside)]];
-	ob = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[TiGetType(tp)]];
+	int oa = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[ta]];
+	int ob = ExtCurStyle->exts_planeOrder[DBTypePlaneTbl[tb]];
 	if (oa > ob)
 	{
 	    /* If the overlapped tile is between the substrate and the boundary
@@ -726,9 +724,8 @@ extSideOverlap(tp, bp)
 	     * from rbp's region due to the area of the sideoverlap, since 
 	     * we now know it is shielded from the substrate.
 	     */
-	    TileType intype = TiGetType(bp->b_inside);
 	    TileType outtype = TiGetType(bp->b_outside);
-	    CapValue subcap = (ExtCurStyle->exts_perimCap[intype][outtype] *
+	    CapValue subcap = (ExtCurStyle->exts_perimCap[ta][outtype] *
 		MIN(areaAccountedFor, length));
 	    rbp->nreg_cap -= subcap;
 	    if (CAP_DEBUG)
@@ -736,8 +733,17 @@ extSideOverlap(tp, bp)
 	} else if (CAP_DEBUG)
 	    extNregAdjustCap(rbp, 0.0, 
 		"obsolete_perimcap (skipped, wrong direction)");
-    }
 
+	/* If the nodes are electrically connected, then we don't add	*/
+        /* any side overlap capacitance to the node.			*/
+	if (rtp == rbp) return (0);
+
+	if (rtp < rbp) ck.ck_1 = rtp, ck.ck_2 = rbp;
+	    else ck.ck_1 = rbp, ck.ck_2 = rtp;
+	he = HashFind(extCoupleHashPtr, (char *) &ck);
+	if (CAP_DEBUG) extAdjustCouple(he, cap, "sideoverlap");
+	extSetCapValue(he, cap + extGetCapValue(he));
+    }
     return (0);
 }
 
